HolisticAI documentation
===================

.. image:: https://img.shields.io/pypi/v/holisticai
.. image:: https://img.shields.io/pypi/dm/holisticai.svg?label=PyPI%20downloads
.. image:: https://img.shields.io/github/license/holistic-ai/holisticai
.. image:: https://readthedocs.org/projects/holisticai/badge/?version=latest

Welcome to the Holistic AI library! This is an open-source tool to assess and improve the trustworthiness of AI systems. The current version of the library offers a set of techniques to easily measure and mitigate Bias across a variety of tasks.  

.. grid:: 4
    :gutter: 0
    :padding: 1 1 0 0

    .. grid-item::
        .. button-link:: https://holisticai.com         
            :class: btn-primary

            :fa:`globe` Holistic AI website

    .. grid-item::
        .. button-link:: https://join.slack.com/t/holisticaicommunity/shared_invite/zt-2jamouyrn-BrMfeoBZIHT8HbLzB3P9QQ 
            :class: btn-primary

            :fab:`slack` Slack Community

.. grid:: 1 2 2 2
    :gutter: 4
    :padding: 2 2 0 0
    :class-container: sd-text-center

    .. grid-item-card:: Getting Started
        :img-top: _static/getting_started.svg
        :class-card: intro-card
        :link: getting_started/index.html
        :link-alt: getting_started
        :shadow: md

        Learn how to install and use the library

    .. grid-item-card:: API Reference
        :img-top: _static/reference.svg
        :class-card: intro-card
        :link: reference/index.html
        :link-alt: reference
        :shadow: md

        Detailed documentation of the library

    .. grid-item-card:: Example Gallery
        :img-top: _static/gallery.svg
        :class-card: intro-card
        :link: gallery/index.html
        :link-alt: tutorials
        :shadow: md

        Examples to get you started with the library

    .. grid-item-card:: Contributing Guide
        :img-top: _static/contributor.svg
        :class-card: intro-card
        :link: contributor/index.html
        :link-alt: contributor
        :shadow: md

        Learn how to contribute to the library

.. admonition:: Learn more about the Holistic AI company
        :class: dropdown admonition-youtube

        .. raw:: html

            <div class="video-container">

        .. youtube:: oY8UYSlsGtg

        .. raw:: html

            </div>

.. toctree::
    :maxdepth: 3
    :hidden:
    :titlesonly:

    getting_started/index
    reference/index
    gallery/index
    contributor/index
    changelog/index